@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -133,8 +133,8 @@ public:
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief get file owner's user id
-  //! \return user id
+  //! \brief Get user id
+  //! \return User id
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   user_id_type
   get_user_id () const override
@@ -143,8 +143,8 @@ public:
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief get file owner's user name
-  //! \return user name
+  //! \brief Get user name
+  //! \return User name
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   std::string
   get_user_name () const override
@@ -153,8 +153,8 @@ public:
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief get file owner's group id
-  //! \return group id
+  //! \brief Get group id
+  //! \return Group id
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   group_id_type
   get_group_id () const override
@@ -163,8 +163,8 @@ public:
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief get file owner's group name
-  //! \return group name
+  //! \brief Get group name
+  //! \return Group name
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   std::string
   get_group_name () const override
@@ -295,7 +295,7 @@ public:
   //! \brief Create a reader for file
   //! \return Pointer to a new created reader_impl
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  virtual reader_type
+  reader_type
   new_reader () const override
   {
     throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
@@ -305,11 +305,115 @@ public:
   //! \brief Create a writer for file
   //! \return Pointer to a new created writer_impl
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  virtual writer_type
+  writer_type
   new_writer (bool) const override
   {
     throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
   }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Set tag
+  //! \param tag Tag name
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  void
+  set_tag (const std::string&) override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Reset tag
+  //! \param tag Tag name
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  void
+  reset_tag (const std::string&) override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Check tag is set
+  //! \param tag Tag name
+  //! \return true/false
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  bool
+  has_tag (const std::string&) const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Get tags
+  //! \return Tags
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  std::set <std::string>
+  get_tags () const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Check if metadata exists
+  //! \param name Metadata name
+  //! \return true/false
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  bool
+  has_metadata (const std::string&) const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Get metadata
+  //! \param name Metadata name
+  //! \return Metadata value
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  mobius::pod::data
+  get_metadata (const std::string&) const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Get all metadata
+  //! \return Metadata values
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  mobius::pod::map
+  get_metadata () const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Set metadata
+  //! \param name Metadata name
+  //! \param value Metadata value
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  void
+  set_metadata (const std::string&, const mobius::pod::data&) override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Remove metadata
+  //! \param name Metadata name
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  void
+  remove_metadata (const std::string&) override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Get streams
+  //! \return Streams
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  std::vector <stream_type>
+  get_streams () const override
+  {
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("invalid file"));
+  }
 };
 
 } // namespace io
