@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -32,7 +32,7 @@
 //! \return true/false
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
-PyMobius_Io_Path_Check (PyObject *pyobj)
+pymobius_io_path_check (PyObject *pyobj)
 {
   return PyObject_IsInstance (pyobj, (PyObject *) &io_path_t);
 }
@@ -43,7 +43,7 @@ PyMobius_Io_Path_Check (PyObject *pyobj)
 //! \return new path object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_Io_Path_from_cpp (mobius::io::path obj)
+pymobius_io_path_to_pyobject (mobius::io::path obj)
 {
   PyObject *ret = _PyObject_New (&io_path_t);
 
@@ -59,7 +59,7 @@ PyMobius_Io_Path_from_cpp (mobius::io::path obj)
 //! \return path object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::io::path
-PyMobius_Io_Path_as_cpp (PyObject *pyobj)
+pymobius_io_path_from_pyobject (PyObject *pyobj)
 {
   if (!PyObject_IsInstance (pyobj, (PyObject *) &io_path_t))
     throw std::invalid_argument (mobius::MOBIUS_EXCEPTION_MSG ("object type must be mobius.io.path"));
@@ -85,7 +85,7 @@ tp_f_get_value (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -110,7 +110,7 @@ tp_f_get_dirname (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -135,7 +135,7 @@ tp_f_get_filename (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -160,7 +160,7 @@ tp_f_get_prefix (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -185,7 +185,7 @@ tp_f_get_extension (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -206,11 +206,11 @@ tp_f_get_parent (io_path_o *self, PyObject *)
 
   try
     {
-      ret = PyMobius_Io_Path_from_cpp (self->obj->get_parent ());
+      ret = pymobius_io_path_to_pyobject (self->obj->get_parent ());
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -235,7 +235,7 @@ tp_f_get_sibling_by_name (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -244,11 +244,11 @@ tp_f_get_sibling_by_name (io_path_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_Io_Path_from_cpp (self->obj->get_sibling_by_name (arg_filename));
+      ret = pymobius_io_path_to_pyobject (self->obj->get_sibling_by_name (arg_filename));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -273,7 +273,7 @@ tp_f_get_sibling_by_extension (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -282,11 +282,11 @@ tp_f_get_sibling_by_extension (io_path_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_Io_Path_from_cpp (self->obj->get_sibling_by_extension (arg_ext));
+      ret = pymobius_io_path_to_pyobject (self->obj->get_sibling_by_extension (arg_ext));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -311,7 +311,7 @@ tp_f_get_child_by_name (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -320,11 +320,11 @@ tp_f_get_child_by_name (io_path_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_Io_Path_from_cpp (self->obj->get_child_by_name (arg_name));
+      ret = pymobius_io_path_to_pyobject (self->obj->get_child_by_name (arg_name));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -349,7 +349,7 @@ tp_f_get_child_by_path (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -358,11 +358,11 @@ tp_f_get_child_by_path (io_path_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_Io_Path_from_cpp (self->obj->get_child_by_path (arg_path));
+      ret = pymobius_io_path_to_pyobject (self->obj->get_child_by_path (arg_path));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -387,7 +387,7 @@ tp_f_is_absolute (io_path_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
@@ -412,7 +412,7 @@ tp_f_filename_match (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -425,7 +425,7 @@ tp_f_filename_match (io_path_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // Return value
@@ -530,7 +530,7 @@ tp_new (PyTypeObject *type, PyObject *args, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_ValueError, e.what ());
+      mobius::py::set_value_error (e.what ());
       return nullptr;
     }
 
@@ -546,7 +546,7 @@ tp_new (PyTypeObject *type, PyObject *args, PyObject *)
       catch (const std::exception& e)
         {
           Py_DECREF (ret);
-          PyErr_SetString (PyExc_Exception, e.what ());
+          mobius::py::set_runtime_error (e.what ());
           ret = nullptr;
         }
     }
@@ -562,7 +562,7 @@ static void
 tp_dealloc (io_path_o *self)
 {
   delete self->obj;
-  self->ob_type->tp_free ((PyObject*) self);
+  Py_TYPE (self)->tp_free ((PyObject*) self);
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -617,4 +617,5 @@ PyTypeObject io_path_t =
   0,                                       		// tp_weaklist
   0,                                       		// tp_del
   0,                                       		// tp_version_tag
+  0,                                       		// tp_finalize
 };
